@@ -21,6 +21,6 @@
 ##
 ###############################################################################
 
-.First.lib <- function(lib,pkg) {
+.onLoad <- function(lib,pkg) {
     library.dynam("mcr", pkg, lib)
 }
